@@ -11,4 +11,8 @@ def clear_text(text):
     value = text.splitlines()
     value =  "".join(value).strip()
     value = value.replace('\t', '')
+    value = value.replace('\\xa0', '')
     return value.strip()
+
+def remove_numbers(text):
+    return ''.join([i for i in text if not i.isdigit()])
